@@ -1,27 +1,34 @@
-/***************************************************************************
-                          IniConfig.h  -  Sidplay2 config file reader.
-                             -------------------
-    begin                : Sun Mar 25 2001
-    copyright            : (C) 2000 by Simon White
-    email                : s_a_white@email.com
- ***************************************************************************/
+/*
+ * This file is part of sidplayfp, a console SID player.
+ *
+ * Copyright 2011-2012 Leandro Nini
+ * Copyright 2000 Simon White
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ */
 
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
-
-#ifndef _IniConfig_h_
-#define _IniConfig_h_
+#ifndef INICONFIG_H
+#define INICONFIG_H
 
 #include "ini/libini.h"
 
 #include <sidplayfp/SidConfig.h>
 
+/*
+ * Sidplayfp config file reader.
+ */
 class IniConfig
 {
 public:
@@ -101,11 +108,11 @@ public:
     void read ();
     operator bool () { return status; }
 
-    // Sidplay2 Specific Section
+    // Sidplayfp Specific Section
     const sidplay2_section&  sidplay2     () { return sidplay2_s; }
     const console_section&   console      () { return console_s; }
     const audio_section&     audio        () { return audio_s; }
     const emulation_section& emulation    () { return emulation_s; }
 };
 
-#endif // _IniConfig_h_
+#endif // INICONFIG_H
