@@ -1,51 +1,55 @@
-/***************************************************************************
-                          args.cpp  -  Command Line Parameters
-                             -------------------
-    begin                : Sun Oct 7 2001
-    copyright            : (C) 2001 by Simon White
-    email                : s_a_white@email.com
- ***************************************************************************/
+/*
+ * This file is part of sidplayfp, a console SID player.
+ *
+ * Copyright 2011-2013 Leandro Nini
+ * Copyright 2000-2001 Simon White
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ */
 
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+#include "player.h"
 
-#include <stdlib.h>
 #include <string.h>
-#include <iostream>
+#include <limits.h>
+
+#ifdef HAVE_UNISTD_H
+#  include <unistd.h>
+#endif
+
 #include <cstdlib>
+#include <iostream>
 
 using std::cout;
 using std::cerr;
 using std::endl;
-#include "player.h"
 
 #ifdef HAVE_SIDPLAYFP_BUILDERS_HARDSID_H
-#   include <sidplayfp/builders/hardsid.h>
-#endif
-
-#if defined(HAVE_SGI)
-#   define DISALLOW_16BIT_SOUND
-#   define DISALLOW_STEREO_SOUND
+#  include <sidplayfp/builders/hardsid.h>
 #endif
 
 
 // Convert time from integer
 bool ConsolePlayer::parseTime (const char *str, uint_least32_t &time)
 {
-    char *sep;
-    uint_least32_t _time;
-
     // Check for empty string
     if (*str == '\0')
         return false;
 
-    sep = (char *) strstr (str, ":");
+    uint_least32_t _time;
+
+    char *sep = (char *) strstr (str, ":");
     if (!sep)
     {   // User gave seconds
         _time = atoi (str);
@@ -82,10 +86,6 @@ bool ConsolePlayer::parseAddress (const char *str, uint_least16_t &address)
 // Parse command line arguments
 int ConsolePlayer::args (int argc, const char *argv[])
 {
-    int  infile = 0;
-    int  i      = 0;
-    bool err    = false;
-
     if (argc == 0) // at least one argument required
     {
         displayArgs ();
@@ -100,6 +100,10 @@ int ConsolePlayer::args (int argc, const char *argv[])
     v1mute = v2mute = v3mute = false;
     v4mute = v5mute = v6mute = false;
 
+    int  infile = 0;
+    int  i      = 0;
+    bool err    = false;
+
     // parse command line arguments
     while ((i < argc) && (argv[i] != NULL))
     {
@@ -418,10 +422,21 @@ int ConsolePlayer::args (int argc, const char *argv[])
         }
         if (!m_timer.valid)
         {
+#if !defined _WIN32 && defined HAVE_UNISTD_H
+            char buffer[PATH_MAX];
+#endif
             const char *database = (m_iniCfg.sidplay2()).database;
             m_timer.length = (m_iniCfg.sidplay2()).playLength;
             if (m_driver.file)
                 m_timer.length = (m_iniCfg.sidplay2()).recordLength;
+#if !defined _WIN32 && defined HAVE_UNISTD_H
+            if (!database || *database == '\0')
+            {
+                snprintf(buffer, PATH_MAX, "%sSonglengths.txt", PKGDATADIR);
+                if (::access(buffer, R_OK) == 0)
+                    database = buffer;
+            }
+#endif
             if (database && (*database != '\0'))
             {   // Try loading the database specificed by the user
                 if (!m_database.open (database))
@@ -514,9 +529,7 @@ void ConsolePlayer::displayArgs (const char *arg)
     }
 #endif
     out << endl
-        // Changed to new homepage address
-        << "Home Page: http://sourceforge.net/projects/sidplay-residfp/" << endl;
-//        << "Mail comments, bug reports, or contributions to <sidplay2@email.com>." << endl;
+        << "Home Page: " PACKAGE_URL << endl;
 }
 
 
