@@ -1,72 +1,84 @@
-/***************************************************************************
-                          player.h  -  Frontend Player
-                             -------------------
-    begin                : Sun Oct 7 2001
-    copyright            : (C) 2001 by Simon White
-    email                : s_a_white@email.com
- ***************************************************************************/
+/*
+ * This file is part of sidplayfp, a console SID player.
+ *
+ * Copyright 2011-2013 Leandro Nini
+ * Copyright 2000-2001 Simon White
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ */
 
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+#ifndef PLAYER_H
+#define PLAYER_H
 
-#ifndef _player_h_
-#define _player_h_
+#ifdef HAVE_CONFIG_H
+#  include "config.h"
+#endif
 
-#include "config.h"
 #include <sidplayfp/SidTune.h>
 #include <sidplayfp/sidplayfp.h>
 #include <sidplayfp/event.h>
 #include <sidplayfp/SidConfig.h>
 #include <sidplayfp/SidTuneInfo.h>
-#ifdef MSVC_HEADER_LOCATIONS
-#include <SidDatabase.h>
-#else
 #include <sidplayfp/SidDatabase.h>
-#endif
-#include "audio/AudioDrv.h"
+
+#include "audio/IAudio.h"
+#include "audio/AudioConfig.h"
+#include "audio/null/null.h"
 #include "IniConfig.h"
 
 #ifdef HAVE_TSID
-#   if HAVE_TSID > 1
-#   include <tsid2/tsid2.h>
-#   define TSID TSID2
-#   else
-#   include <tsid/tsid.h>
-#   endif
+#  if HAVE_TSID > 1
+#    include <tsid2/tsid2.h>
+#    define TSID TSID2
+#  else
+#    include <tsid/tsid.h>
+#  endif
 #endif
 
-typedef enum {black, red, green, yellow, blue, magenta, cyan, white}
+typedef enum { black, red, green, yellow, blue, magenta, cyan, white }
     player_colour_t;
-typedef enum {tableStart, tableMiddle, tableSeperator, tableEnd}
+typedef enum { tableStart, tableMiddle, tableSeperator, tableEnd }
     player_table_t;
-typedef enum {
+typedef enum
+{
     playerError = 0, playerRunning, playerPaused, playerStopped,
     playerRestart, playerExit, playerFast = 128,
     playerFastRestart = playerRestart | playerFast,
     playerFastExit = playerExit | playerFast
 } player_state_t;
 
-typedef enum {/* Same as EMU_DEFAULT except no soundcard.
-                 Still allows wav generation */
-              EMU_NONE = 0,
-              /* The following require a soundcard */
-              EMU_DEFAULT, EMU_RESIDFP, EMU_RESID,
-              /* The following should disable the soundcard */
-              EMU_HARDSID, EMU_SIDSTATION, EMU_COMMODORE,
-              EMU_SIDSYN, EMU_END} SIDEMUS;
+typedef enum
+{
+    /* Same as EMU_DEFAULT except no soundcard.
+    Still allows wav generation */
+    EMU_NONE = 0,
+    /* The following require a soundcard */
+    EMU_DEFAULT, EMU_RESIDFP, EMU_RESID,
+    /* The following should disable the soundcard */
+    EMU_HARDSID, EMU_SIDSTATION, EMU_COMMODORE,
+    EMU_SIDSYN, EMU_END} SIDEMUS;
 
-typedef enum {/* Define possible output sources */
-              OUT_NULL = 0,
-              /* Hardware */
-              OUT_SOUNDCARD,
-              /* File creation support */
-              OUT_WAV, OUT_AU, OUT_END} OUTPUTS;
+typedef enum
+{
+    /* Define possible output sources */
+    OUT_NULL = 0,
+    /* Hardware */
+    OUT_SOUNDCARD,
+    /* File creation support */
+    OUT_WAV, OUT_AU, OUT_END
+} OUTPUTS;
 
 // Error and status message numbers.
 enum
@@ -137,8 +149,8 @@ private:
         SIDEMUS        sid;      // Sid emulation
         bool           file;     // File based driver
         AudioConfig    cfg;
-        AudioBase*     selected; // Selected Output Driver
-        AudioBase*     device;   // HW/File Driver
+        IAudio*        selected; // Selected Output Driver
+        IAudio*        device;   // HW/File Driver
         Audio_Null     null;     // Used for everything
     } m_driver;
 
@@ -189,7 +201,9 @@ private:
 
     const char* getModel (SidTuneInfo::model_t model);
 
-    uint8_t* loadRom    (const char* romPath, const int size, const char defaultRom[]);
+    uint8_t* loadRom(const char* romPath, const int size, const char defaultRom[]);
+
+    IAudio* getWavFile(const SidTuneInfo *tuneInfo);
 
 public:
     ConsolePlayer (const char * const name);
@@ -203,4 +217,4 @@ public:
     player_state_t state (void) { return m_state; }
 };
 
-#endif // _player_h_
+#endif // PLAYER_H
